import request from '@/utils/request'

// 电力变配电所
export function chartDlbpds(params) {
  return request({
    url: '/chart/dlbpds',
    method: 'get',
    params
  })
}

// 电力变配电所本月兑现情况
export function chartDlbpdsby(params) {
  return request({
    url: '/chart/dlbpdsby',
    method: 'get',
    params
  })
}

// 电力受电线路
export function chartDlsdxl(params) {
  return request({
    url: '/chart/dlsdxl',
    method: 'get',
    params
  })
}

// 电力受电线路本月
export function chartDlsdxlBy(params) {
  return request({
    url: '/chart/dlsdxlby',
    method: 'get',
    params
  })
}

// 电力远动调试
export function chartDlydts(params) {
  return request({
    url: '/chart/dlydts',
    method: 'get',
    params
  })
}

// 电力远动调试本月
export function chartDlydtsby(params) {
  return request({
    url: '/chart/dlydtsby',
    method: 'get',
    params
  })
}

// 检修兑现情况
export function chartJxdxqky(params) {
  return request({
    url: '/chart/jxdxqk',
    method: 'get',
    params
  })
}

// 检修兑现情况本月
export function chartJxdxqkyby(params) {
  return request({
    url: '/chart/jxdxqkby',
    method: 'get',
    params
  })
}

// map
export function chartMap(params) {
  return request({
    url: '/chart/map',
    method: 'get',
    params
  })
}

// 牵变、电力设备巡检兑现（本月）
export function chartQbdlsbxjdx(params) {
  return request({
    url: '/chart/qbdlsbxjdx',
    method: 'get',
    params
  })
}

// 试验计划本月兑现情况
export function chartSyjhbydxqk(params) {
  return request({
    url: '/chart/syjhbydxqk',
    method: 'get',
    params
  })
}

// 试验计划兑现情况
export function chartSyjhdxqk(params) {
  return request({
    url: '/chart/syjhdxqk',
    method: 'get',
    params
  })
}

export function chartMapTable(params) {
  return request({
    url: '/chart/map/table',
    method: 'get',
    params
  })
}

export function bdycList(params) {
  return request({
    url: '/show/bdyc/list',
    method: 'get',
    params
  })
}

export function dlycList(params) {
  return request({
    url: '/show/dlyc/list',
    method: 'get',
    params
  })
}

export function chartTodoList(url, parameter) {
  return request({
    url: '/chart/todoList',
    params: parameter,
    method: 'get'
  })
}


export function chartDlydtsbyDetail(url, parameter) {
  return request({
    url: '/chart/dlydtsby/detail',
    params: parameter,
    method: 'get'
  })
}
export function chartDlsdxlbyDetail(url, parameter) {
  return request({
    url: '/chart/dlsdxlby/detail',
    params: parameter,
    method: 'get'
  })
}

export function chartDlbpdsbyDetail(url, parameter) {
  return request({
    url: '/chart/dlbpdsby/detail',
    params: parameter,
    method: 'get'
  })
}
